@@ -45,7 +45,7 @@ class Input:
         self.screen.addstr(self.y, self.x, self.label, curses.A_REVERSE)
         self.screen.move(self.y+2, self.x+2+self.pos)
         curses.curs_set(1)
-        self.show_content_pos = len(self.content)
+        self.show_content_pos = len(self.content)-1
 
         while(True):
             key_str = self.screen.getkey()
@@ -58,7 +58,7 @@ class Input:
                     self.screen.addstr(self.y, self.x, self.label)
                     curses.curs_set(0)
                     return key_str
-                elif((key_str == "KEY_LEFT") and (self.pos == 0) and ((self.show_content_pos - len(self.show_content)) < 0)):
+                elif((key_str == "KEY_LEFT") and (self.pos == 0) and ((self.show_content_pos - len(self.show_content)) <= 0)):
                     self.screen.addstr(self.y, self.x, self.label)
                     curses.curs_set(0)
                     return key_str
@@ -121,7 +121,7 @@ class Input:
             # TRAVEL INPUT TO LEFT
             if not (pos == 0):
                 self.pos -= 1
-            elif(pos == 0 and ((self.show_content_pos - len_show_content) >= 1)):
+            elif(pos == 0 and ((self.show_content_pos - len_show_content) > 0)):
                 self.show_content = self.content[self.show_content_pos - len_show_content] + self.show_content[:-1]
                 self.show_content_pos -= 1
 
@@ -158,7 +158,6 @@ class Input:
         else:
             self.show_content = self.content[(self.show_content_pos-len_show_content)+1:self.show_content_pos+1]
 
-
     def move(self, x ,y):
 
         for i in range(0, self.width+1):
